{
    "$graph": [
        {
            "class": "Workflow",
            "doc": "ChIP-seq - Quantification - samples: treatment and control",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/input_ctrl_bam_files"
                },
                {
                    "type": "File",
                    "id": "#main/input_genome_sizes"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/input_trt_bam_files"
                },
                {
                    "default": 1,
                    "type": "int",
                    "id": "#main/nthreads"
                }
            ],
            "steps": [
                {
                    "run": "#deeptools-bigwigcompare.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#main/bamCompare-ctrl-subtracted-rpkm/bigwig1",
                        "#main/bamCompare-ctrl-subtracted-rpkm/bigwig2"
                    ],
                    "in": [
                        {
                            "source": "#main/bamCoverage-rpkm-trt/output_bam_coverage",
                            "id": "#main/bamCompare-ctrl-subtracted-rpkm/bigwig1"
                        },
                        {
                            "source": "#main/bamCoverage-rpkm-ctrl/output_bam_coverage",
                            "id": "#main/bamCompare-ctrl-subtracted-rpkm/bigwig2"
                        },
                        {
                            "valueFrom": "${return 1}",
                            "id": "#main/bamCompare-ctrl-subtracted-rpkm/binSize"
                        },
                        {
                            "source": "#main/nthreads",
                            "id": "#main/bamCompare-ctrl-subtracted-rpkm/numberOfProcessors"
                        },
                        {
                            "valueFrom": "subtract",
                            "id": "#main/bamCompare-ctrl-subtracted-rpkm/operation"
                        },
                        {
                            "valueFrom": "bigwig",
                            "id": "#main/bamCompare-ctrl-subtracted-rpkm/outFileFormat"
                        },
                        {
                            "valueFrom": ".ctrl_subtracted.bw",
                            "id": "#main/bamCompare-ctrl-subtracted-rpkm/output_suffix"
                        }
                    ],
                    "out": [
                        "#main/bamCompare-ctrl-subtracted-rpkm/output"
                    ],
                    "id": "#main/bamCompare-ctrl-subtracted-rpkm"
                },
                {
                    "run": "#deeptools-bamcoverage.cwl",
                    "in": [
                        {
                            "source": "#main/input_ctrl_bam_files",
                            "id": "#main/bamCoverage-rpkm-ctrl/bam"
                        },
                        {
                            "valueFrom": "${return 1}",
                            "id": "#main/bamCoverage-rpkm-ctrl/binSize"
                        },
                        {
                            "valueFrom": "${return 200}",
                            "id": "#main/bamCoverage-rpkm-ctrl/extendReads"
                        },
                        {
                            "valueFrom": "RPKM",
                            "id": "#main/bamCoverage-rpkm-ctrl/normalizeUsing"
                        },
                        {
                            "source": "#main/nthreads",
                            "id": "#main/bamCoverage-rpkm-ctrl/numberOfProcessors"
                        },
                        {
                            "valueFrom": "bigwig",
                            "id": "#main/bamCoverage-rpkm-ctrl/outFileFormat"
                        },
                        {
                            "valueFrom": ".rpkm.bw",
                            "id": "#main/bamCoverage-rpkm-ctrl/output_suffix"
                        }
                    ],
                    "scatter": "#main/bamCoverage-rpkm-ctrl/bam",
                    "out": [
                        "#main/bamCoverage-rpkm-ctrl/output_bam_coverage"
                    ],
                    "id": "#main/bamCoverage-rpkm-ctrl"
                },
                {
                    "run": "#deeptools-bamcoverage.cwl",
                    "scatter": "#main/bamCoverage-rpkm-trt/bam",
                    "in": [
                        {
                            "source": "#main/input_trt_bam_files",
                            "id": "#main/bamCoverage-rpkm-trt/bam"
                        },
                        {
                            "valueFrom": "${return 1}",
                            "id": "#main/bamCoverage-rpkm-trt/binSize"
                        },
                        {
                            "valueFrom": "${return 200}",
                            "id": "#main/bamCoverage-rpkm-trt/extendReads"
                        },
                        {
                            "valueFrom": "RPKM",
                            "id": "#main/bamCoverage-rpkm-trt/normalizeUsing"
                        },
                        {
                            "source": "#main/nthreads",
                            "id": "#main/bamCoverage-rpkm-trt/numberOfProcessors"
                        },
                        {
                            "valueFrom": "bigwig",
                            "id": "#main/bamCoverage-rpkm-trt/outFileFormat"
                        },
                        {
                            "valueFrom": ".rpkm.bw",
                            "id": "#main/bamCoverage-rpkm-trt/output_suffix"
                        }
                    ],
                    "out": [
                        "#main/bamCoverage-rpkm-trt/output_bam_coverage"
                    ],
                    "id": "#main/bamCoverage-rpkm-trt"
                },
                {
                    "run": "#bedGraphToBigWig.cwl",
                    "in": [
                        {
                            "source": "#main/bedsort_genomecov/bed_file_sorted",
                            "id": "#main/bdg2bw-raw/bed_graph"
                        },
                        {
                            "source": "#main/input_genome_sizes",
                            "id": "#main/bdg2bw-raw/genome_sizes"
                        },
                        {
                            "valueFrom": ".raw.bw",
                            "id": "#main/bdg2bw-raw/output_suffix"
                        }
                    ],
                    "scatter": "#main/bdg2bw-raw/bed_graph",
                    "out": [
                        "#main/bdg2bw-raw/output_bigwig"
                    ],
                    "id": "#main/bdg2bw-raw"
                },
                {
                    "run": "#bedSort.cwl",
                    "scatter": "#main/bedsort_genomecov/bed_file",
                    "in": [
                        {
                            "source": "#main/bedtools_genomecov/output_bedfile",
                            "id": "#main/bedsort_genomecov/bed_file"
                        }
                    ],
                    "out": [
                        "#main/bedsort_genomecov/bed_file_sorted"
                    ],
                    "id": "#main/bedsort_genomecov"
                },
                {
                    "run": "#bedtools-genomecov.cwl",
                    "scatter": "#main/bedtools_genomecov/ibam",
                    "in": [
                        {
                            "valueFrom": "${return true}",
                            "id": "#main/bedtools_genomecov/bg"
                        },
                        {
                            "source": "#main/input_genome_sizes",
                            "id": "#main/bedtools_genomecov/g"
                        },
                        {
                            "source": "#main/input_trt_bam_files",
                            "id": "#main/bedtools_genomecov/ibam"
                        }
                    ],
                    "out": [
                        "#main/bedtools_genomecov/output_bedfile"
                    ],
                    "id": "#main/bedtools_genomecov"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "doc": "Fragment extended RPKM bigWig (signal) control files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/bamCoverage-rpkm-ctrl/output_bam_coverage",
                    "id": "#main/bigwig_ctrl_rpkm_extended_files"
                },
                {
                    "doc": "Control subtracted fragment extended RPKM bigWig (signal) files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/bamCompare-ctrl-subtracted-rpkm/output",
                    "id": "#main/bigwig_ctrl_subtracted_rpkm_extended_files"
                },
                {
                    "doc": "Raw reads bigWig (signal) files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/bdg2bw-raw/output_bigwig",
                    "id": "#main/bigwig_raw_files"
                },
                {
                    "doc": "Fragment extended RPKM bigWig (signal) files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/bamCoverage-rpkm-trt/output_bam_coverage",
                    "id": "#main/bigwig_rpkm_extended_files"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "doc": "Tool:    bedtools genomecov (aka genomeCoverageBed)\nVersion: v2.25.0\nSummary: Compute the coverage of a feature file among a genome.\n\nUsage: bedtools genomecov [OPTIONS] -i <bed/gff/vcf> -g <genome>\n\nOptions: \n\t-ibam\t\tThe input file is in BAM format.\n\t\t\tNote: BAM _must_ be sorted by position\n\n\t-d\t\tReport the depth at each genome position (with one-based coordinates).\n\t\t\tDefault behavior is to report a histogram.\n\n\t-dz\t\tReport the depth at each genome position (with zero-based coordinates).\n\t\t\tReports only non-zero positions.\n\t\t\tDefault behavior is to report a histogram.\n\n\t-bg\t\tReport depth in BedGraph format. For details, see:\n\t\t\tgenome.ucsc.edu/goldenPath/help/bedgraph.html\n\n\t-bga\t\tReport depth in BedGraph format, as above (-bg).\n\t\t\tHowever with this option, regions with zero \n\t\t\tcoverage are also reported. This allows one to\n\t\t\tquickly extract all regions of a genome with 0 \n\t\t\tcoverage by applying: \"grep -w 0$\" to the output.\n\n\t-split\t\tTreat \"split\" BAM or BED12 entries as distinct BED intervals.\n\t\t\twhen computing coverage.\n\t\t\tFor BAM files, this uses the CIGAR \"N\" and \"D\" operations \n\t\t\tto infer the blocks for computing coverage.\n\t\t\tFor BED12 files, this uses the BlockCount, BlockStarts, and BlockEnds\n\t\t\tfields (i.e., columns 10,11,12).\n\n\t-strand\t\tCalculate coverage of intervals from a specific strand.\n\t\t\tWith BED files, requires at least 6 columns (strand is column 6). \n\t\t\t- (STRING): can be + or -\n\n\t-5\t\tCalculate coverage of 5\" positions (instead of entire interval).\n\n\t-3\t\tCalculate coverage of 3\" positions (instead of entire interval).\n\n\t-max\t\tCombine all positions with a depth >= max into\n\t\t\ta single bin in the histogram. Irrelevant\n\t\t\tfor -d and -bedGraph\n\t\t\t- (INTEGER)\n\n\t-scale\t\tScale the coverage by a constant factor.\n\t\t\tEach coverage value is multiplied by this factor before being reported.\n\t\t\tUseful for normalizing coverage by, e.g., reads per million (RPM).\n\t\t\t- Default is 1.0; i.e., unscaled.\n\t\t\t- (FLOAT)\n\n\t-trackline\tAdds a UCSC/Genome-Browser track line definition in the first line of the output.\n\t\t\t- See here for more details about track line definition:\n\t\t\t      http://genome.ucsc.edu/goldenPath/help/bedgraph.html\n\t\t\t- NOTE: When adding a trackline definition, the output BedGraph can be easily\n\t\t\t      uploaded to the Genome Browser as a custom track,\n\t\t\t      BUT CAN NOT be converted into a BigWig file (w/o removing the first line).\n\n\t-trackopts\tWrites additional track line definition parameters in the first line.\n\t\t\t- Example:\n\t\t\t   -trackopts 'name=\"My Track\" visibility=2 color=255,30,30'\n\t\t\t   Note the use of single-quotes if you have spaces in your parameters.\n\t\t\t- (TEXT)\n\nNotes: \n\t(1) The genome file should tab delimited and structured as follows:\n\t <chromName><TAB><chromSize>\n\n\tFor example, Human (hg19):\n\tchr1\t249250621\n\tchr2\t243199373\n\t...\n\tchr18_gl000207_random\t4262\n\n\t(2) The input BED (-i) file must be grouped by chromosome.\n\t A simple \"sort -k 1,1 <BED> > <BED>.sorted\" will suffice.\n\n\t(3) The input BAM (-ibam) file must be sorted by position.\n\t A \"samtools sort <BAM>\" should suffice.\n\nTips: \n\tOne can use the UCSC Genome Browser's MySQL database to extract\n\tchromosome sizes. For example, H. sapiens:\n\n\tmysql --user=genome --host=genome-mysql.cse.ucsc.edu -A -e \\\n\t\"select chrom, size from hg19.chromInfo\" > hg19.genome",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/bedtools",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-3"
                    },
                    "doc": "\tCalculate coverage of 3\" positions (instead of entire interval).\n",
                    "id": "#bedtools-genomecov.cwl/3"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-5"
                    },
                    "doc": "\tCalculate coverage of 5\" positions (instead of entire interval).\n",
                    "id": "#bedtools-genomecov.cwl/5"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-bg"
                    },
                    "doc": "\tReport depth in BedGraph format. For details, see:\ngenome.ucsc.edu/goldenPath/help/bedgraph.html\n",
                    "id": "#bedtools-genomecov.cwl/bg"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-bga"
                    },
                    "doc": "\tReport depth in BedGraph format, as above (-bg).\nHowever with this option, regions with zero\ncoverage are also reported. This allows one to\nquickly extract all regions of a genome with 0\ncoverage by applying: \"grep -w 0$\" to the output.\n",
                    "id": "#bedtools-genomecov.cwl/bga"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-d"
                    },
                    "doc": "\tReport the depth at each genome position (with one-based coordinates).\nDefault behavior is to report a histogram.\n",
                    "id": "#bedtools-genomecov.cwl/d"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-dz"
                    },
                    "doc": "\tReport the depth at each genome position (with zero-based coordinates).\nReports only non-zero positions.\nDefault behavior is to report a histogram.\n",
                    "id": "#bedtools-genomecov.cwl/dz"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3,
                        "prefix": "-g"
                    },
                    "doc": "<genome sizes>",
                    "id": "#bedtools-genomecov.cwl/g"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-ibam"
                    },
                    "doc": "\tThe input file is in BAM format.\nNote: BAM _must_ be sorted by position\n",
                    "id": "#bedtools-genomecov.cwl/ibam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-max"
                    },
                    "doc": "\tCombine all positions with a depth >= max into\na single bin in the histogram. Irrelevant\nfor -d and -bedGraph\n- (INTEGER)\n",
                    "id": "#bedtools-genomecov.cwl/max"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-scale"
                    },
                    "doc": "\tScale the coverage by a constant factor.\nEach coverage value is multiplied by this factor before being reported.\nUseful for normalizing coverage by, e.g., reads per million (RPM).\n- Default is 1.0; i.e., unscaled.\n- (FLOAT)\n",
                    "id": "#bedtools-genomecov.cwl/scale"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-split"
                    },
                    "doc": "\tTreat \"split\" BAM or BED12 entries as distinct BED intervals.\nwhen computing coverage.\nFor BAM files, this uses the CIGAR \"N\" and \"D\" operations\nto infer the blocks for computing coverage.\nFor BED12 files, this uses the BlockCount, BlockStarts, and BlockEnds\nfields (i.e., columns 10,11,12).\n",
                    "id": "#bedtools-genomecov.cwl/split"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-strand"
                    },
                    "doc": "\tCalculate coverage of intervals from a specific strand.\nWith BED files, requires at least 6 columns (strand is column 6).\n- (STRING): can be + or -\n",
                    "id": "#bedtools-genomecov.cwl/strand"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-trackline"
                    },
                    "doc": "Adds a UCSC/Genome-Browser track line definition in the first line of the output.\n- See here for more details about track line definition:\nhttp://genome.ucsc.edu/goldenPath/help/bedgraph.html\n- NOTE: When adding a trackline definition, the output BedGraph can be easily\nuploaded to the Genome Browser as a custom track,\nBUT CAN NOT be converted into a BigWig file (w/o removing the first line).\n",
                    "id": "#bedtools-genomecov.cwl/trackline"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-trackopts"
                    },
                    "doc": "Writes additional track line definition parameters in the first line.\n- Example:\n-trackopts 'name=\"My Track\" visibility=2 color=255,30,30'\nNote the use of single-quotes if you have spaces in your parameters.\n- (TEXT)\n",
                    "id": "#bedtools-genomecov.cwl/trackopts"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.ibam.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + '.bdg')"
                    },
                    "id": "#bedtools-genomecov.cwl/output_bedfile"
                }
            ],
            "baseCommand": [
                "bedtools",
                "genomecov"
            ],
            "stdout": "$(inputs.ibam.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + '.bdg')",
            "id": "#bedtools-genomecov.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Tool:   bedGraphToBigWig v 4 - Convert a bedGraph file to bigWig format.",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/ucsc-kentutils:1.0",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "\tbed_graph is a four column file in the format: <chrom> <start> <end> <value>\n",
                    "id": "#bedGraphToBigWig.cwl/bed_graph"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "\tgenome_sizes is two column: <chromosome name> <size in bases>.\n",
                    "id": "#bedGraphToBigWig.cwl/genome_sizes"
                },
                {
                    "type": "string",
                    "default": ".bw",
                    "id": "#bedGraphToBigWig.cwl/output_suffix"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bed_graph.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, \"\") + inputs.output_suffix)"
                    },
                    "id": "#bedGraphToBigWig.cwl/output_bigwig"
                }
            ],
            "baseCommand": "bedGraphToBigWig",
            "arguments": [
                {
                    "valueFrom": "$(inputs.bed_graph.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, \"\") + inputs.output_suffix)",
                    "position": 3
                }
            ],
            "id": "#bedGraphToBigWig.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "bedSort - Sort a .bed file by chrom,chromStart\nusage:\n   bedSort in.bed out.bed\nin.bed and out.bed may be the same.\n",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/ucsc-kentutils:1.0",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "Bed or bedGraph file to be sorted",
                    "id": "#bedSort.cwl/bed_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bed_file.path.replace(/^.*[\\\\\\/]/, '') + \"_sorted\")"
                    },
                    "id": "#bedSort.cwl/bed_file_sorted"
                }
            ],
            "baseCommand": "bedSort",
            "arguments": [
                {
                    "valueFrom": "$(inputs.bed_file.path.replace(/^.*[\\\\\\/]/, '') + \"_sorted\")",
                    "position": 2
                }
            ],
            "id": "#bedSort.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "usage: An example usage is:$ bamCoverage -b reads.bam -o coverage.bw\n\nThis tool takes an alignment of reads or fragments as input (BAM file) and\ngenerates a coverage track (bigWig or bedGraph) as output. The coverage is\ncalculated as the number of reads per bin, where bins are short consecutive\ncounting windows of a defined size. It is possible to extended the length of\nthe reads to better reflect the actual fragment length. *bamCoverage* offers\nnormalization by scaling factor, Reads Per Kilobase per Million mapped reads\n(RPKM), and 1x depth (reads per genome coverage, RPGC).\nRequired arguments:\n  --bam BAM file, -b BAM file\n                        BAM file to process (default: None)\nOutput:\n  --outFileName FILENAME, -o FILENAME\n                        Output file name. (default: None)\n  --outFileFormat {bigwig,bedgraph}, -of {bigwig,bedgraph}\n                        Output file type. Either \"bigwig\" or \"bedgraph\".\n                        (default: bigwig)\nOptional arguments:\n  --help, -h            show this help message and exit\n  --scaleFactor SCALEFACTOR\n                        The smooth length defines a window, larger than the\n                        binSize, to average the number of reads. For example,\n                        if the \u2013binSize is set to 20 and the \u2013smoothLength is\n                        set to 60, then, for each bin, the average of the bin\n                        and its left and right neighbors is considered.\n                        Any value smaller than \u2013binSize will be ignored and\n                        no smoothing will be applied. (default: 1.0)\n  --MNase               Determine nucleosome positions from MNase-seq data.\n                        Only 3 nucleotides at the center of each fragment are\n                        counted. The fragment ends are defined by the two mate\n                        reads. Only fragment lengthsbetween 130 - 200 bp are\n                        considered to avoid dinucleosomes or other\n                        artifacts.*NOTE*: Requires paired-end data. A bin size\n                        of 1 is recommended. (default: False)\n  --filterRNAstrand {forward,reverse}\n                        Selects RNA-seq reads (single-end or paired-end) in\n                        the given strand. (default: None)\n  --version             show program's version number and exit\n  --binSize INT bp, -bs INT bp\n                        Size of the bins, in bases, for the output of the\n                        bigwig/bedgraph file. (default: 50)\n  --region CHR:START:END, -r CHR:START:END\n                        Region of the genome to limit the operation to - this\n                        is useful when testing parameters to reduce the\n                        computing time. The format is chr:start:end, for\n                        example --region chr10 or --region\n                        chr10:456700:891000. (default: None)\n  --blackListFileName BED file, -bl BED file\n                        A BED file containing regions that should be excluded\n                        from all analyses. Currently this works by rejecting\n                        genomic chunks that happen to overlap an entry.\n                        Consequently, for BAM files, if a read partially\n                        overlaps a blacklisted region or a fragment spans over\n                        it, then the read/fragment might still be considered.\n                        (default: None)\n  --numberOfProcessors INT, -p INT\n                        Number of processors to use. Type \"max/2\" to use half\n                        the maximum number of processors or \"max\" to use all\n                        available processors. (default: max/2)\n  --verbose, -v         Set to see processing messages. (default: False)\nRead coverage normalization options:\n  --normalizeTo1x EFFECTIVE GENOME SIZE LENGTH\n                        Report read coverage normalized to 1x sequencing depth\n                        (also known as Reads Per Genomic Content (RPGC)).\n                        Sequencing depth is defined as: (total number of\n                        mapped reads * fragment length) / effective genome\n                        size. The scaling factor used is the inverse of the\n                        sequencing depth computed for the sample to match the\n                        1x coverage. To use this option, the effective genome\n                        size has to be indicated after the option. The\n                        effective genome size is the portion of the genome\n                        that is mappable. Large fractions of the genome are\n                        stretches of NNNN that should be discarded. Also, if\n                        repetitive regions were not included in the mapping of\n                        reads, the effective genome size needs to be adjusted\n                        accordingly. Common values are: mm9: 2,150,570,000;\n                        hg19:2,451,960,000; dm3:121,400,000 and\n                        ce10:93,260,000. See Table 2 of http://www.plosone.org\n                        /article/info:doi/10.1371/journal.pone.0030377 or http\n                        ://www.nature.com/nbt/journal/v27/n1/fig_tab/nbt.1518_\n                        T1.html for several effective genome sizes. (default:\n                        None)\n--ignoreForNormalization IGNOREFORNORMALIZATION [IGNOREFORNORMALIZATION ...]\n                        A list of space-delimited chromosome names containing\n                        those chromosomes that should be excluded for\n                        computing the normalization. This is useful when\n                        considering samples with unequal coverage across\n                        chromosomes, like male samples. An usage examples is\n                        --ignoreForNormalization chrX chrM. (default: None)\n  --skipNonCoveredRegions, --skipNAs\n                        This parameter determines if non-covered regions\n                        (regions without overlapping reads) in a BAM file\n                        should be skipped. The default is to treat those\n                        regions as having a value of zero. The decision to\n                        skip non-covered regions depends on the interpretation\n                        of the data. Non-covered regions may represent, for\n                        example, repetitive regions that should be skipped.\n                        (default: False)\n  --smoothLength INT bp\n                        The smooth length defines a window, larger than the\n                        binSize, to average the number of reads. For example,\n                        if the --binSize is set to 20 and the --smoothLength\n                        is set to 60, then, for each bin, the average of the\n                        bin and its left and right neighbors is considered.\n                        Any value smaller than --binSize will be ignored and\n                        no smoothing will be applied. (default: None)\nRead processing options:\n  --extendReads [INT bp], -e [INT bp]\n                        This parameter allows the extension of reads to\n                        fragment size. If set, each read is extended, without\n                        exception. *NOTE*: This feature is generally NOT\n                        recommended for spliced-read data, such as RNA-seq, as\n                        it would extend reads over skipped regions. *Single-\n                        end*: Requires a user specified value for the final\n                        fragment length. Reads that already exceed this\n                        fragment length will not be extended. *Paired-end*:\n                        Reads with mates are always extended to match the\n                        fragment size defined by the two read mates. Unmated\n                        reads, mate reads that map too far apart (>4x fragment\n                        length) or even map to different chromosomes are\n                        treated like single-end reads. The input of a fragment\n                        length value is optional. If no value is specified, it\n                        is estimated from the data (mean of the fragment size\n                        of all mate reads). (default: False)\n  --ignoreDuplicates    If set, reads that have the same orientation and start\n                        position will be considered only once. If reads are\n                        paired, the mate's position also has to coincide to\n                        ignore a read. (default: False)\n  --minMappingQuality INT\n                        If set, only reads that have a mapping quality score\n                        of at least this are considered. (default: None)\n  --centerReads         By adding this option, reads are centered with respect\n                        to the fragment length. For paired-end data, the read\n                        is centered at the fragment length defined by the two\n                        ends of the fragment. For single-end data, the given\n                        fragment length is used. This option is useful to get\n                        a sharper signal around enriched regions. (default:\n                        False)\n  --samFlagInclude INT  Include reads based on the SAM flag. For example, to\n                        get only reads that are the first mate, use a flag of\n                        64. This is useful to count properly paired reads only\n                        once, as otherwise the second mate will be also\n                        considered for the coverage. (default: None)\n  --samFlagExclude INT  Exclude reads based on the SAM flag. For example, to\n                        get only reads that map to the forward strand, use\n                        --samFlagExclude 16, where 16 is the SAM flag for\n                        reads that map to the reverse strand. (default: None)\n",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/deeptools:3.0.1",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--MNase"
                    },
                    "doc": "Determine nucleosome positions from MNase-seq data.\nOnly 3 nucleotides at the center of each fragment are\ncounted. The fragment ends are defined by the two mate\nreads. Only fragment lengthsbetween 130 - 200 bp are\nconsidered to avoid dinucleosomes or other\nartifacts.*NOTE*: Requires paired-end data. A bin size\nof 1 is recommended. (default: False)\n",
                    "id": "#deeptools-bamcoverage.cwl/MNase"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--bam"
                    },
                    "doc": "BAM file to process ",
                    "id": "#deeptools-bamcoverage.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--binSize"
                    },
                    "doc": "INT bp\nSize of the bins, in bases, for the output of the\nbigwig/bedgraph file. (default: 50)\n",
                    "id": "#deeptools-bamcoverage.cwl/binSize"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--blackListFileName"
                    },
                    "doc": "BED file\nA BED file containing regions that should be excluded\nfrom all analyses. Currently this works by rejecting\ngenomic chunks that happen to overlap an entry.\nConsequently, for BAM files, if a read partially\noverlaps a blacklisted region or a fragment spans over\nit, then the read/fragment might still be considered.\n(default: None)\n",
                    "id": "#deeptools-bamcoverage.cwl/blackListFileName"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--centerReads"
                    },
                    "doc": "By adding this option, reads are centered with respect\nto the fragment length. For paired-end data, the read\nis centered at the fragment length defined by the two\nends of the fragment. For single-end data, the given\nfragment length is used. This option is useful to get\na sharper signal around enriched regions. (default:\nFalse)\n",
                    "id": "#deeptools-bamcoverage.cwl/centerReads"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--extendReads"
                    },
                    "doc": "INT bp\nThis parameter allows the extension of reads to\nfragment size. If set, each read is extended, without\nexception. *NOTE*: This feature is generally NOT\nrecommended for spliced-read data, such as RNA-seq, as\nit would extend reads over skipped regions. *Single-\nend*: Requires a user specified value for the final\nfragment length. Reads that already exceed this\nfragment length will not be extended. *Paired-end*:\nReads with mates are always extended to match the\nfragment size defined by the two read mates. Unmated\nreads, mate reads that map too far apart (>4x fragment\nlength) or even map to different chromosomes are\ntreated like single-end reads. The input of a fragment\nlength value is optional. If no value is specified, it\nis estimated from the data (mean of the fragment size\nof all mate reads). (default: False)\n",
                    "id": "#deeptools-bamcoverage.cwl/extendReads"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--filterRNAstrand"
                    },
                    "doc": "{forward,reverse}\nSelects RNA-seq reads (single-end or paired-end) in\nthe given strand. (default: None)\n",
                    "id": "#deeptools-bamcoverage.cwl/filterRNAstrand"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--ignoreDuplicates"
                    },
                    "doc": "If set, reads that have the same orientation and start\nposition will be considered only once. If reads are\npaired, the mate's position also has to coincide to\nignore a read. (default: False)\n",
                    "id": "#deeptools-bamcoverage.cwl/ignoreDuplicates"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--ignoreForNormalization"
                    },
                    "doc": "A list of space-delimited chromosome names containing those chromosomes\nthat should be excluded for computing the normalization. This is useful\nwhen considering samples with unequal coverage across chromosomes, like\nmale samples. An usage examples is \u2013ignoreForNormalization chrX chrM.\n",
                    "id": "#deeptools-bamcoverage.cwl/ignoreForNormalization"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--minMappingQuality"
                    },
                    "doc": "INT\nIf set, only reads that have a mapping quality score\nof at least this are considered. (default: None)\n",
                    "id": "#deeptools-bamcoverage.cwl/minMappingQuality"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--normalizeUsing"
                    },
                    "doc": "Possible choices: RPKM, CPM, BPM, RPGC\n\nUse one of the entered methods to normalize the number of reads per bin.\nBy default, no normalization is performed. RPKM = Reads Per Kilobase per\nMillion mapped reads; CPM = Counts Per Million mapped reads, same as\nCPM in RNA-seq; BPM = Bins Per Million mapped reads, same as TPM in\nRNA-seq; RPGC = reads per genomic content (1x normalization);\nMapped reads are considered after blacklist filtering (if applied).\nRPKM (per bin) = number of reads per bin / (number of mapped reads (in millions) * bin length (kb)).\nCPM (per bin) = number of reads per bin / number of mapped reads (in millions).\nBPM (per bin) = number of reads per bin / sum of all reads per bin (in millions).\nRPGC (per bin) = number of reads per bin / scaling factor for 1x average coverage.\nThis scaling factor, in turn, is determined from the sequencing depth:\n(total number of mapped reads * fragment length) / effective genome size.\nThe scaling factor used is the inverse of the sequencing depth\ncomputed for the sample to match the 1x coverage.\nThis option requires \u2013effectiveGenomeSize.\nEach read is considered independently, if you want to only count one\nmate from a pair in paired-end data, then use\nthe \u2013samFlagInclude/\u2013samFlagExclude options.\n",
                    "id": "#deeptools-bamcoverage.cwl/normalizeUsing"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--numberOfProcessors"
                    },
                    "doc": "INT\nNumber of processors to use. Type \"max/2\" to use half\nthe maximum number of processors or \"max\" to use all\navailable processors. (default: max/2)\n",
                    "id": "#deeptools-bamcoverage.cwl/numberOfProcessors"
                },
                {
                    "type": "string",
                    "default": "bigwig",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outFileFormat"
                    },
                    "doc": "{bigwig,bedgraph}, -of {bigwig,bedgraph}\nOutput file type. Either \"bigwig\" or \"bedgraph\".\n(default: bigwig)\n",
                    "id": "#deeptools-bamcoverage.cwl/outFileFormat"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "FILENAME\nOutput file name. (default: input BAM filename with bigwig [*.bw] or bedgraph [*.bdg] extension.)\n",
                    "id": "#deeptools-bamcoverage.cwl/outFileName"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Suffix used for output file (input BAM filename + suffix)",
                    "id": "#deeptools-bamcoverage.cwl/output_suffix"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--region"
                    },
                    "doc": "CHR:START:END\nRegion of the genome to limit the operation to - this\nis useful when testing parameters to reduce the\ncomputing time. The format is chr:start:end, for\nexample --region chr10 or --region\nchr10:456700:891000. (default: None)\n",
                    "id": "#deeptools-bamcoverage.cwl/region"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--samFlagExclude"
                    },
                    "doc": "INT  \nExclude reads based on the SAM flag. For example, to\nget only reads that map to the forward strand, use\n--samFlagExclude 16, where 16 is the SAM flag for\nreads that map to the reverse strand. (default: None)\n",
                    "id": "#deeptools-bamcoverage.cwl/samFlagExclude"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--samFlagInclude"
                    },
                    "doc": "INT  \nInclude reads based on the SAM flag. For example, to\nget only reads that are the first mate, use a flag of\n64. This is useful to count properly paired reads only\nonce, as otherwise the second mate will be also\nconsidered for the coverage. (default: None)\n",
                    "id": "#deeptools-bamcoverage.cwl/samFlagInclude"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--scaleFactor"
                    },
                    "doc": "The smooth length defines a window, larger than the\nbinSize, to average the number of reads. For example,\nif the \u2013binSize is set to 20 and the \u2013smoothLength is\nset to 60, then, for each bin, the average of the bin\nand its left and right neighbors is considered.\nAny value smaller than \u2013binSize will be ignored and\nno smoothing will be applied. (default: 1.0)\n",
                    "id": "#deeptools-bamcoverage.cwl/scaleFactor"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--skipNonCoveredRegions"
                    },
                    "doc": "--skipNonCoveredRegions, --skipNAs\nThis parameter determines if non-covered regions\n(regions without overlapping reads) in a BAM file\nshould be skipped. The default is to treat those\nregions as having a value of zero. The decision to\nskip non-covered regions depends on the interpretation\nof the data. Non-covered regions may represent, for\nexample, repetitive regions that should be skipped.\n(default: False)\n",
                    "id": "#deeptools-bamcoverage.cwl/skipNonCoveredRegions"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--smoothLength"
                    },
                    "doc": "INT bp\nThe smooth length defines a window, larger than the\nbinSize, to average the number of reads. For example,\nif the --binSize is set to 20 and the --smoothLength\nis set to 60, then, for each bin, the average of the\nbin and its left and right neighbors is considered.\nAny value smaller than --binSize will be ignored and\nno smoothing will be applied. (default: None)\nRead processing options:\n",
                    "id": "#deeptools-bamcoverage.cwl/smoothLength"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--verbose"
                    },
                    "doc": "--verbose         \nSet to see processing messages. (default: False)\n",
                    "id": "#deeptools-bamcoverage.cwl/verbose"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--version"
                    },
                    "doc": "show program's version number and exit",
                    "id": "#deeptools-bamcoverage.cwl/version"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${ if (inputs.outFileName) return inputs.outFileName; if (inputs.output_suffix) return inputs.bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + inputs.output_suffix; if (inputs.outFileFormat == \"bedgraph\") return inputs.bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".bdg\"; return inputs.bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".bw\"; }"
                    },
                    "id": "#deeptools-bamcoverage.cwl/output_bam_coverage"
                }
            ],
            "baseCommand": "bamCoverage",
            "arguments": [
                {
                    "valueFrom": "${ if (inputs.outFileName) return inputs.outFileName; if (inputs.output_suffix) return inputs.bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + inputs.output_suffix; if (inputs.outFileFormat == \"bedgraph\") return inputs.bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".bdg\"; return inputs.bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".bw\"; }",
                    "prefix": "--outFileName",
                    "position": 3
                }
            ],
            "id": "#deeptools-bamcoverage.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "usage: bigwigCompare [-h] [--version] [--binSize INT bp]\n                     [--region CHR:START:END] [--numberOfProcessors INT]\n                     [--verbose] --outFileName FILENAME\n                     [--outFileFormat {bigwig,bedgraph}] --bigwig1 Bigwig file\n                     --bigwig2 Bigwig file [--scaleFactors SCALEFACTORS]\n                     [--pseudocount PSEUDOCOUNT]\n                     [--ratio {log2,ratio,subtract,add,reciprocal_ratio}]\n                     [--skipNonCoveredRegions]\nThis tool compares two bigWig files based on the number of mapped reads. To compare the bigWig files, the genome is partitioned into bins of equal size, then the number of reads found in each BAM file are counted per bin and finally a summary value is reported. This value can be the ratio of the number of readsper bin, the log2 of the ratio, the sum or the difference. optional arguments:\n  -h, --help            show this help message and exit\n  --bigwig1 Bigwig file, -b1 Bigwig file\n                        Bigwig file 1. Usually the file for the treatment.\n                        (default: None)\n  --bigwig2 Bigwig file, -b2 Bigwig file\n                        Bigwig file 2. Usually the file for the control.\n                        (default: None)\n  --scaleFactors SCALEFACTORS\n                        Set this parameter to multipy the bigwig values by a\n                        constant. The format is scaleFactor1:scaleFactor2. For\n                        example 0.7:1 to scale the first bigwig file by 0.7\n                        while not scaling the second bigwig file (default:\n                        None)\n  --pseudocount PSEUDOCOUNT\n                        small number to avoid x/0. Only useful when ratio =\n                        log2 or ratio (default: 1)\n  --ratio {log2,ratio,subtract,add,reciprocal_ratio}\n                        The default is to compute the log2(ratio) between the\n                        two samples. The reciprocal ratio returns the the\n                        negative of the inverse of the ratio if the ratio is\n                        less than 0. The resulting values are interpreted as\n                        negative fold changes. Other possible operations are :\n                        simple ratio, subtraction, sum (default: log2)\n  --skipNonCoveredRegions, --skipNAs\n                        This parameter determines if non-covered regions\n                        (regions without a score) in the bigWig files should\n                        be skipped. The default is to treat those regions as\n                        having a value of zero. The decision to skip non-\n                        covered regions depends on the interpretation of the\n                        data. Non-covered regions in a bigWig file may\n                        represent repetitive regions that should be skipped.\n                        Alternatively, the interpretation of non-covered\n                        regions as zeros may be wrong and this option should\n                        be used (default: False)\nOptional arguments:\n  --version             show program's version number and exit\n  --binSize INT bp, -bs INT bp\n                        Size of the bins, in bases, for the output of the\n                        bigwig/bedgraph file. (default: 50)\n  --region CHR:START:END, -r CHR:START:END\n                        Region of the genome to limit the operation to - this\n                        is useful when testing parameters to reduce the\n                        computing time. The format is chr:start:end, for\n                        example --region chr10 or --region\n                        chr10:456700:891000. (default: None)\n  --numberOfProcessors INT, -p INT\n                        Number of processors to use. Type \"max/2\" to use half\n                        the maximum number of processors or \"max\" to use all\n                        available processors. (default: max/2)\n  --verbose, -v         Set to see processing messages. (default: False)\nOutput:\n  --outFileName FILENAME, -o FILENAME\n                        Output file name. (default: None)\n  --outFileFormat {bigwig,bedgraph}, -of {bigwig,bedgraph}\n                        Output file type. Either \"bigwig\" or \"bedgraph\".\n                        (default: bigwig)",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/deeptools:3.0.1",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--bigwig1"
                    },
                    "doc": "Bigwig file, -b1 Bigwig file\nBigwig file 1. Usually the file for the treatment.\n(default: None)\n",
                    "id": "#deeptools-bigwigcompare.cwl/bigwig1"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--bigwig2"
                    },
                    "doc": "Bigwig file, -b2 Bigwig file\nBigwig file 2. Usually the file for the control.\n(default: None)\n",
                    "id": "#deeptools-bigwigcompare.cwl/bigwig2"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--binSize"
                    },
                    "doc": "INT bp, -bs INT bp\nSize of the bins, in bases, for the output of the\nbigwig/bedgraph file. (default: 50)\n",
                    "id": "#deeptools-bigwigcompare.cwl/binSize"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--numberOfProcessors"
                    },
                    "doc": "INT, -p INT\nNumber of processors to use. Type \"max/2\" to use half\nthe maximum number of processors or \"max\" to use all\navailable processors. (default: max/2)\n",
                    "id": "#deeptools-bigwigcompare.cwl/numberOfProcessors"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--operation"
                    },
                    "doc": "The default is to output the log2ratio of the two\nsamples. The reciprocal ratio returns the the negative\nof the inverse of the ratio if the ratio is less than\n0. The resulting values are interpreted as negative\nfold changes. *NOTE*: Only with --operation subtract\ncan --normalizeUsing RPGC or --normalizeUsing RPKM be\nused. Instead of performing a computation using both\nfiles, the scaled signal can alternatively be output\nfor the first or second file using the '--operation\nfirst' or '--operation second' (default: log2)\n",
                    "id": "#deeptools-bigwigcompare.cwl/operation"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outFileFormat"
                    },
                    "doc": "{bigwig,bedgraph}, -of {bigwig,bedgraph}\nOutput file type. Either \"bigwig\" or \"bedgraph\".\n(default: bigwig)\n",
                    "id": "#deeptools-bigwigcompare.cwl/outFileFormat"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "FILENAME, -o FILENAME\nOutput file name. (default: None)\n",
                    "id": "#deeptools-bigwigcompare.cwl/outFileName"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Suffix used to replace bigwig1 extension (please, include extension)\n",
                    "id": "#deeptools-bigwigcompare.cwl/output_suffix"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--pseudocount"
                    },
                    "doc": "PSEUDOCOUNT\nsmall number to avoid x/0. Only useful when ratio =\nlog2 or ratio (default: 1)\n",
                    "id": "#deeptools-bigwigcompare.cwl/pseudocount"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--region"
                    },
                    "doc": "CHR:START:END, -r CHR:START:END\nRegion of the genome to limit the operation to - this\nis useful when testing parameters to reduce the\ncomputing time. The format is chr:start:end, for\nexample --region chr10 or --region\nchr10:456700:891000. (default: None)\n",
                    "id": "#deeptools-bigwigcompare.cwl/region"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--scaleFactors"
                    },
                    "doc": "SCALEFACTORS\nSet this parameter to multipy the bigwig values by a\nconstant. The format is scaleFactor1:scaleFactor2. For\nexample 0.7:1 to scale the first bigwig file by 0.7\nwhile not scaling the second bigwig file (default:\nNone)\n",
                    "id": "#deeptools-bigwigcompare.cwl/scaleFactors"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--verbose"
                    },
                    "doc": "--verbose\nSet to see processing messages. (default: False)\n",
                    "id": "#deeptools-bigwigcompare.cwl/verbose"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--version"
                    },
                    "doc": "            show program's version number and exit\n",
                    "id": "#deeptools-bigwigcompare.cwl/version"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${ if (inputs.outFileName) return inputs.outFileName; if (inputs.output_suffix) return inputs.bigwig1.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + inputs.output_suffix; if (inputs.outFileFormat == \"bedgraph\") return inputs.bigwig1.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".compared.bdg\"; return inputs.bigwig1.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".compared.bw\"; }"
                    },
                    "id": "#deeptools-bigwigcompare.cwl/output"
                }
            ],
            "baseCommand": "bigwigCompare",
            "arguments": [
                {
                    "valueFrom": "${ if (inputs.outFileName) return inputs.outFileName; if (inputs.output_suffix) return inputs.bigwig1.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + inputs.output_suffix; if (inputs.outFileFormat == \"bedgraph\") return inputs.bigwig1.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".compared.bdg\"; return inputs.bigwig1.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".compared.bw\"; }",
                    "prefix": "--outFileName",
                    "position": 3
                }
            ],
            "id": "#deeptools-bigwigcompare.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
